////////////////////////////////////////////////////////////////
//                                              //
////////////////////////////////////////////////////////////////

unit UPlayList;

interface

uses  MPlayer, FileCtrl, ExtCtrls;

type
     TPlayList = class     //   
     private
       FPlayer :TMediaPlayer;                       // 
       FList   :TFileListBox;                       //  
       FTimer  :TTimer;                             // 
       function Index:longint;                      //   
       function PlayFile(S:string):boolean;         //   S
       procedure TimerTimer(Sender: TObject);       //  
     public
       constructor Create;                          //  
       destructor Destroy; override;                //  
       procedure Play;                              // 
       procedure Stop;                              // 
       property Player:TMediaPlayer write FPlayer;  // 
       property List:TFileListBox   write FList;    //  
     end;

var  PlayList :TPlayList;   // 

implementation

uses  SysUtils;

function TPlayList.Index:longint;  //   
begin
     result:=-1;  if FList.Items.Count=0 then Exit;
     if FList.FileName<>'' then
        result:=FList.Items.IndexOf(ExtractFileName(FList.FileName));
     if result<0 then result:=0;
end;

function TPlayList.PlayFile(S:string):boolean;  //   S
begin
     result:=false;
     if (FPlayer=nil) or (FList=nil) or (not FileExists(S)) then Exit;
     FList.FileName:=S;
     FPlayer.FileName:=S;
     FPlayer.Open;
     FPlayer.Play;
     result:=true;
end;

procedure TPlayList.TimerTimer(Sender: TObject); //  
var  N,K :longint;  //   ,   
     S   :string;   //  
begin
     if (FPlayer=nil) or (FList=nil) or
        (FList.Items.Count=0) or (FPlayer.Mode=mpPlaying) then Exit;
     N:=Index;  K:=0;
     Repeat
           N:=N+1;  if N>=FList.Items.Count then begin N:=0; K:=K+1; end;
           S:=FList.Items.Strings[N];
     Until FileExists(S) or (K>2);
     PlayFile(S);
end;

constructor TPlayList.Create;  //  
begin
     FPlayer := nil;
     FList   := nil;
     FTimer  := TTimer.Create(nil);
     FTimer.Enabled:=false;
     FTimer.Interval:=100;
     FTimer.OnTimer:=TimerTimer;
end;

destructor TPlayList.Destroy;  //  
begin
     FTimer.Free;
end;

procedure TPlayList.Play;  // 
var  N :longint;  //  
begin
     if FTimer=nil then Exit;
     N:=Index;  if N<0 then Exit;
     if PlayFile(FList.Items.Strings[N]) then FTimer.Enabled:=true;
end;

procedure TPlayList.Stop;  // 
begin
     if (FPlayer<>nil) and (FPlayer.Mode=mpPlaying) then FPlayer.Stop;
     if FTimer<>nil  then FTimer.Enabled:=false;
end;

initialization
    PlayList := TPlayList.Create;  //  
finalization
    PlayList.Free;                 //  
end.
